@@ -6,22 +6,16 @@ from jemu_mem_peripheral import JemuMemPeripheral
 
 
 class JemuBQ27421(JemuMemPeripheral):
-    _COMMAND = "command"
-    _TYPE_STRING = "type"
-    _PERIPHERAL_ID = "peripheral_id"
     _INTERRUPT = "interrupts"
-    _PERIPHERAL_TYPE = "peripheral_type"
     _COMMAND_SET_INTERRUPT = "set_interrupt"
+    _COMMAND = "command"
 
-    def __init__(self, jemu_connection, id, peripheral_type, generators):
-        JemuMemPeripheral.__init__(self, jemu_connection, id, peripheral_type, generators)
+    def __init__(self, jemu_connection, name, peripheral_type, generators):
+        JemuMemPeripheral.__init__(self, jemu_connection, name, peripheral_type, generators)
 
     def _battery_interrupt_json(self):
         return {
-            self._TYPE_STRING: self._COMMAND,
-            self._PERIPHERAL_ID: self._id,
             self._COMMAND: self._COMMAND_SET_INTERRUPT,
-            self._PERIPHERAL_TYPE: self._peripheral_type
         }
 
     def interrupt(self):
@@ -29,4 +23,4 @@ class JemuBQ27421(JemuMemPeripheral):
         This function activates an interrupt in the bq27421 peripheral.
         On interrupt a 1 ms pulse is sent out over gpout pin.
         """
-        self._jemu_connection.send_json(self._battery_interrupt_json())
+        self._jemu_connection.send_command_async(self._battery_interrupt_json(), self._name, self._peripheral_type)
