@@ -22,7 +22,7 @@ class TestWebApi(unittest.TestCase):
     def test_uninit_upload_file(self):
         self.api._user_uid = None
         with self.assertRaises(UnInitializedError):
-            self.api.upload_file('test_file', b'SOME_BINARY_DATA')
+            self.api._upload_file('test_file', b'SOME_BINARY_DATA')
 
     def test_upload_file(self):
-        self.api.upload_file('test_file.bin', b'SOME_BINARY_DATA')
+        self.api._upload_file('test_file.bin', b'SOME_BINARY_DATA')
